@@ -18,14 +18,19 @@ setMethod("add_view", signature(taxlist="taxlist"),
             ViewID <- ViewID:(ViewID + length(new_view[[1]]) - 1)
             new_view <- list(ViewID=ViewID, ...)
             for(i in colnames(taxlist@taxonViews)[
-                    !colnames(taxlist@taxonViews) %in% names(new_view)]) {
+					!colnames(taxlist@taxonViews) %in% names(new_view)]) {
                 new_view[[i]] <- rep(NA, length(ViewID))
             }
-            taxlist@taxonViews <- do.call(rbind,
-                    list(taxlist@taxonViews,
-                            new_view[match(colnames(taxlist@taxonViews),
-                                            names(new_view))],
-                            stringsAsFactors=FALSE))
+			new_view <- as.data.frame(new_view, stringsAsFactors=FALSE)
+			if(nrow(taxlist@taxonViews) > 0) {
+				old_view <- taxlist@taxonViews
+				for(i in colnames(new_view)[!colnames(new_view) %in%
+								colnames(old_view)]) {
+					old_view[,i] <- rep(NA, nrow(old_view))
+				}
+				new_view <- do.call(rbind, list(old_view, new_view))
+			}
+			taxlist@taxonViews <- new_view
             return(taxlist)
         }
 )
