@@ -13,9 +13,11 @@ setGeneric("delete_name",
 setMethod("delete_name", signature(taxlist="taxlist", UsageID="numeric"),
 		function(taxlist, UsageID, ...) {
 			if(any(UsageID %in% taxlist@taxonRelations$AcceptedName))
-				stop("Values in 'UsageID' are not allowed to be accepted names in 'taxlist'.")
+				stop(paste("Values in 'UsageID' are not allowed to be",
+								"accepted names in 'taxlist'."))
 			if(any(UsageID %in% taxlist@taxonRelations$Basionym))
-				stop("Values in 'UsageID' are not allowed to be basionyms in 'taxlist'.")
+				stop(paste("Values in 'UsageID' are not allowed to be",
+								"basionyms in 'taxlist'."))
 			taxlist@taxonNames <- taxlist@taxonNames[
 					!taxlist@taxonNames$TaxonUsageID %in% UsageID,]
 			return(taxlist)
