@@ -12,5 +12,11 @@ add_trait <- function() {
 }
 
 add_level <- function() {
-	.Deprecated(msg="'add_level' is deprecated. Use 'levels' or 'update_concept' instead.")
+	.Deprecated(msg=paste("'add_level' is deprecated. Use 'levels' or",
+					"'update_concept' instead."))
+}
+
+replace_view <- function() {
+	.Deprecated(msg=paste("'replace_view' is deprecated. Use",
+					"'update_concept' instead."))
 }
