@@ -17,15 +17,20 @@ setMethod("tax2traits", signature(object="taxlist"),
 					TaxonConceptID=object@taxonRelations$TaxonConceptID,
 					stringsAsFactors=FALSE)
 			# first entry with concepts at level
-			for(i in levels(object)) {
+			if(all(is.na(object@taxonRelations$Level)))
+				stop("Input object without taxonomic ranks.")
+			if(all(is.na(object@taxonRelations$Parent)))
+				stop("Input object without any parent-child relationships.")
+			for(i in taxlist::levels(object)) {
 				ID <- object@taxonRelations[
 						paste(object@taxonRelations$Level) == i,
 						"TaxonConceptID"]
 				TAX[,i] <- ID[match(object@taxonRelations$TaxonConceptID, ID)]
 			}
 			# second entry parents
-			for(i in levels(object)[-length(levels(object))]) {
-				if(!all(is.na(TAX[,i])) & !all(!is.na(TAX[,i]))) {
+			for(i in taxlist::levels(object)[
+					-length(taxlist::levels(object))]) {
+				if(!all(is.na(TAX[,i]))) {
 					TAX <- split(TAX, is.na(TAX[,i]))
 					ID <- TAX[["FALSE"]][,i]
 					PAR <- object@taxonRelations[match(ID,
@@ -42,30 +47,17 @@ setMethod("tax2traits", signature(object="taxlist"),
 										ID_2)]
 					}
 					TAX <- do.call(rbind, TAX)
-				} else {
-					if(all(!is.na(TAX[,i]))) {
-						ID <- TAX[,i]
-						PAR <- object@taxonRelations[match(ID,
-										object@taxonRelations$TaxonConceptID),
-								"Parent"]
-						LEV <- paste(object@taxonRelations[match(PAR,
-												object@taxonRelations$TaxonConceptID),
-										"Level"])
-						LEV[LEV == "NA"] <- NA
-						for(j in unique(LEV[!is.na(LEV)])) {
-							ID_2 <- ID[LEV == j]
-							PAR_2 <- PAR[LEV == j]
-							TAX[,j] <- PAR_2[match(TAX[,i], ID_2)]
-						}
-					}
 				}
 			}
+			# supress empty columns
+			TAX <- TAX[,apply(TAX, 2, function(x) !all(is.na(x)))]
 			colnames(TAX)[colnames(TAX) == "TaxonConceptID"] <- "ConceptID"
 			object <- do.call(update_trait, c(list(taxlist=object),
 							as.list(TAX)))
 			if(get_names) {
 				Names <- accepted_name(object)
-				for(i in paste(levels(object))) {
+				for(i in taxlist::levels(object)[taxlist::levels(object) %in%
+								colnames(TAX)]) {
 					object@taxonTraits[,i] <- Names[
 							match(object@taxonTraits[,i], Names$TaxonConceptID),
 							"TaxonName"]
